( cd opt/kde/share/doc/HTML/sk/koshell ; rm -rf common )
( cd opt/kde/share/doc/HTML/sk/koshell ; ln -sf /opt/kde/share/doc/HTML/sk/common common )
( cd opt/kde/share/doc/HTML/sk/kpresenter ; rm -rf common )
( cd opt/kde/share/doc/HTML/sk/kpresenter ; ln -sf /opt/kde/share/doc/HTML/sk/common common )
